Use the new CPUModel enum names from libpeci

libpeci was updated with new CPUModel names, so update uses here to
match.

Change-Id: I60db4ea624bdb8defe3d937cc48fb798e5f49207
Signed-off-by: Jason M. Bills <jason.m.bills@intel.com>
diff --git a/src/cpuinfo_main.cpp b/src/cpuinfo_main.cpp
index 78c82b5..7670bbd 100644
--- a/src/cpuinfo_main.cpp
+++ b/src/cpuinfo_main.cpp
@@ -56,7 +56,7 @@
     "xyz.openbmc_project.Smbios.MDR_V2";
 
 // constants for reading SSPEC or QDF string from PIROM
 // Currently, they are the same for platforms with icx
 static constexpr uint8_t defaultI2cBus = 13;
 static constexpr uint8_t defaultI2cSlaveAddr0 = 0x50;
 static constexpr uint8_t sspecRegAddr = 0xd;
@@ -409,13 +409,13 @@
 
     switch (model)
     {
-        case icx:
-        case icxd:
-        case spr:
-        case emr:
-        case gnr:
-        case gnrd:
-        case srf:
+        case iceLake:
+        case iceLakeD:
+        case sapphireRapids:
+        case emeraldRapids:
+        case graniteRapids:
+        case graniteRapidsD:
+        case sierraForest:
         {
             // PPIN can be read through PCS 19
             static constexpr uint8_t u8Size = 4; // default to a DWORD
@@ -56,7 +56,7 @@
 
 // constants for reading SSPEC or QDF string from PIROM
-// Currently, they are the same for platforms with icx
+// Currently, they are the same for platforms with Ice Lake
 static constexpr uint8_t defaultI2cBus = 13;
 static constexpr uint8_t defaultI2cSlaveAddr0 = 0x50;